# -*- coding: utf-8 -*-

from random import randint

DICES = [
  "LENUYG",
  "ELUPST",
  "ZDVNEA",
  "SDTNOE",
  "AMORIS",
  "FXRAOI",
  "MOQABJ",
  "FSHEEI",
  "HRSNEI",
  "ETNKOU",
  "TARILB",
  "TIEAOA",
  "ACEPDM",
  "RLASEC",
  "ULIWER",
  "VGTNIE"
  ]

def load_dico(file_name):
  """Load and return a dictionary from file. 

  Keyword arguments:
  file_name (string) -- name of the file, may contains the path,
    otherwise the file must be in the same directory.

  Return value:
  (list(str)) -- a list of strings containing each word read in the file.
  """
  dico = []
  f = open(file_name)
  for word in f.readlines():
    dico.append(word.strip())
  return dico

def get_dices():
  """Return a list of 16 dices.

  Keyword arguments:
  (None) -- Nothing.
  
  Return value:
  (list(str)) -- a list containing 16 strings. Each string contains 6 characters representing each face of a dice.
  
  """
  return DICES

##def create_grid(dices_list):
##  """Create a random 4x4 grid with the dices.
##
##  Keyword arguments:
##  dices (list(str)) -- List containing the 16 dices, each dice is represented by a 6 characters string.
##  
##  Return value:
##  (list(list(str))) -- a list of list representing the grid of characters.
##  """
##  grid = []
##  dices = dices_list[:]
##  nums = list(range(len(dices)))
##  for line in range(4):
##    grid.append([])
##    for column in range(4):
##      dice_nbr = randint(0, len(dices)-1)
##      dice_face = randint(0,5)
##      grid[line].append(dices[dice_nbr][dice_face])
##      del dices[dice_nbr]
##  return grid
  

def show_grid(grid):
  """Print the grid on the screen.

  Keyword arguments:
  grid (list(list(str))) -- list of list containing the characters of the grid to display.
  
  Return value:
  (None) -- Nothing.
  """
  for line in grid:
    for char in line:
      print(char,end=' ')
    print()

##
##def ask_word():
##  """Ask the user to enter a word. Verify the length and the content of the input.
##
##  Keyword arguments:
##  (None)
##  
##  Return value:
##  (str) -- string containing the word in uppercase.
##  """
##  end = False
##  while not end:
##    word = str(input('Veuillez entrer un mot : '))
##    if (word.isalpha() and len(word) >= 3) or (word == ''):
##      end = True
##    else:
##      print('Le mot entré ne convient pas, il ne peut contenir que des lettres et sa longueur minimale est de 3.')
##  return word.upper()
##
##def get_points(word):
##  """Define the points associated with a given length of word.
##
##  Keyword arguments:
##  word (str) -- string containing the word to evaluate.
##  
##  Return value:
##  (int) -- an integer representing the points given for a word.
##  """
##  length = len(word)
##  if(length >= 8):
##    return 11
##  elif(length == 7):
##    return 5
##  elif(length == 6):
##    return 3
##  elif(length == 5):
##    return 2
##  elif(length >= 3):
##    return 1
##  return 0
##
##def is_in_grid(word, grid):
##  """Check if the word is anywhere in the grid.
##
##  Keyword arguments:
##  word (str) -- string containing the word to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display.
##  
##  Return value:
##  (boolean) -- True if the word is found, False otherwise.
##  """
##  for l in range(4):
##    for c in range(4):
##      if is_word_in_place(word, grid, l, c):
##        return True
##  return False
##
##def is_word_in_place(word, grid, line, col):
##  """Check if the word is in the grid starting at position (line, col).
##
##  Keyword arguments:
##  word (str) -- string containing the word to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid, where the word begins;
##  column (int) -- column of the grid, where the word begins.
##  
##  Return value:
##  (boolean) -- True if the word is found, False otherwise.
##  """
##  found = True
##  checked_list = [(-1, -1)]
##  i = 1
##  while i < len(word):
##    if((line, col) in checked_list):
##      found = False
##      i = len(word)
##    else:
##      checked_list.append((line, col))
##      (line, col) = find_neighbour(word[i], grid, line, col)
##    i += 1
##  return found
##
##
##def find_neighbour(letter, grid, line, col):
##  """Find letter in the neighbour of (line, col).
##  Return the position of a possible occurence of letter
##  as a neighbour of position (line, col) in the grid.
##  Return (-1, -1) if letter is not a neighbour of (line, col).
##
##  Keyword arguments:
##  letter (str) -- string containing the character to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid;
##  column (int) -- column of the grid.
##  
##  Return value:
##  (int) -- line of the neighbour;
##  (int) -- column of the neighbour.
##  """
##  if is_north(letter, grid, line, col):
##    line -= 1
##  elif is_south(letter, grid, line, col):
##    line += 1
##  elif is_west(letter, grid, line, col):
##    col -= 1
##  elif is_east(letter, grid, line, col):
##    col += 1
##  else:
##    (line, col) = (-1, -1)
##  return (line, col)
##
##def is_north(letter, grid, line, col):
##  """Check if the letter is at the north of (line, col). Return True if this is the case.
##
##  Keyword arguments:
##  letter (str) -- string containing the character to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid;
##  column (int) -- column of the grid.
##  
##  Return value:
##  (boolean) -- True if the letter is found north, False otherwise.
##  """
##  return line > 0 and grid[line - 1][col] == letter           
##
##def is_south(letter, grid, line, col):
##  """Check if the letter is at the south of (line, col). Return True if this is the case.
##
##  Keyword arguments:
##  letter (str) -- string containing the character to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid;
##  column (int) -- column of the grid.
##  
##  Return value:
##  (boolean) -- True if the letter is found south, False otherwise.
##  """
##  return line < len(grid) - 1 and grid[line + 1][col] == letter
##            
##def is_west(letter, grid, line, col):
##  """Check if the letter is at the west of (line, col). Return True if this is the case.
##
##  Keyword arguments:
##  letter (str) -- string containing the character to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid;
##  column (int) -- column of the grid.
##  
##  Return value:
##  (boolean) -- True if the letter is found west, False otherwise.
##  """
##  return col > 0 and grid[line][col - 1] == letter
##           
##def is_east(letter, grid, line, col):
##  """Check if the letter is at the east of (line, col). Return True if this is the case.
##
##  Keyword arguments:
##  letter (str) -- string containing the character to find;
##  grid (list(list(str))) -- list of list containing the characters of the grid to display;
##  line (int) -- line of the grid;
##  column (int) -- column of the grid.
##  
##  Return value:
##  (boolean) -- True if the letter is found east, False otherwise.
##  """
##  return col < len(grid[0]) - 1 and grid[line][col + 1] == letter
##

def ask_yes_no(message):
  """Return 'True' if a user's answer to the message received in arameter is 'o', and 'False' if it's answer is 'n'. 
  The question is asked until the answer is either 'o' or 'n'.

  Keyword arguments:
  message(str) -- string containing the question to display to the user.
  
  Return value:
  (boolean) -- True if the answer is 'o', False otherwise.
  """
  answer = input(message+" o/n ").lower()
  while answer != "o" and answer != "n":
      answer = input(message+" o/n ").lower()
  return answer == "o"

##
##def boggle():
##  """Launch the boggle, only one game.
##
##  Keyword arguments:
##  (None) -- Nothing.
##  
##  Return value:
##  (None) -- Nothing.
##  """
##  dico = load_dico("dico.txt")
##  dices = get_dices()
##  grid = bg.create_grid(dices)
##  game_continue = True
##  score = 0
##  while game_continue:
##    bg.show_grid(grid)
##    word = bg.ask_word()    
##    if word != '':
##      if bg.is_in_grid(word, grid) and (word in dico):
##        score += bg.get_points(word)
##        print("Bravo, vous avez trouvé un mot, votre score est de : " + str(score))
##      else:
##        score -= bg.get_points(word)
##        print("Dommage : " + str(score))
##    else:
##      print('Fin du jeu, vous avez obtenu un score de : ' + str(score))
##      game_continue = False

##if __name__ == "__main__":
##  cont = True
##  while cont:
##    boggle()
##    cont = ask_yes_no("Voulez-vous faire une nouvelle partie ?")
    
  #input()
